SecurityHeadersConfig

Struct SecurityHeadersConfig 

pub struct SecurityHeadersConfig { /* private fields */ }
Secure-by-default response header configuration.

Implementations

Source

impl SecurityHeadersConfig

pub fn validate(&self) -> Result<(), AppError>

Validate the configuration.

Errors

Returns an error when the configuration cannot be safely applied.

pub const fn with_transport_security( self, transport_security: TransportSecurity, ) -> SecurityHeadersConfig

Select the transport security mode.

pub fn with_content_security_policy( self, value: Option<String>, ) -> SecurityHeadersConfig

Override the Content Security Policy header. Pass None to disable it.

pub fn with_permissions_policy( self, value: Option<String>, ) -> SecurityHeadersConfig

Override the Permissions Policy header. Pass None to disable it.

pub fn with_referrer_policy( self, value: Option<String>, ) -> SecurityHeadersConfig

Override the Referrer Policy header. Pass None to disable it.

pub fn with_frame_options(self, value: Option<String>) -> SecurityHeadersConfig

Override the X-Frame-Options header. Pass None to disable it.

pub fn with_content_type_options( self, value: Option<String>, ) -> SecurityHeadersConfig

Override the X-Content-Type-Options header. Pass None to disable it.

pub fn header_pairs(&self) -> Result<Vec<(HeaderName, HeaderValue)>, AppError>

Build validated header pairs for transport adapters.

Errors

Returns an error when a configured header value is invalid.